@@ -23,7 +23,7 @@ sub profile_check_in
 {
 	my ( $self, $p, $default) = @_;
 	$self-> SUPER::profile_check_in( $p, $default);
-	%{ $p-> {gl_config} } = (%{ $p-> {gl_config} } ,%{ $default-> {gl_config} } )
+	%{ $p-> {gl_config} } = (%{ $default-> {gl_config} }, %{ $p-> {gl_config} })
 		if $p-> {gl_config};
 }
 
@@ -128,6 +128,16 @@ in L<Prima::OpenGL/Selection of a GL visual>.
 
 =back
 
+=head2 Events
+
+=over
+
+=item on_size
+
+By default, sets C<glViewport> to the new widget size. Override C<on_size> if that is not desired.
+
+=back
+
 =head1 AUTHOR
 
 Dmitry Karasik, E<lt>dmitry@karasik.eu.orgE<gt>.
